leer
=====

Experimental cryptocurrency written in python; implements LubbaDubDub technology to conceal transacted volume.

**Leer is in alpha-testing phase. Coins on testnet will NOT have any value and will NOT be transferred to mainnet.**

## Requirements
Currently works only on linux.

* Python 3.5+
* pip
* g++, cffi, build-essential for `lmdb` package

## Installation
`pip install leer`

## Run node
Download [start script](https://github.com/WTRMQDev/leer/blob/master/scripts/start_node.py), adjust config and run. Web interface should be available on configured rpc port.

## Run testnet miner
Download [miner script](https://github.com/WTRMQDev/leer/blob/master/scripts/miner.py), adjust config (host and port) and run.
